@@ -2,9 +2,10 @@ use strict;
 use warnings;
 
 package Scientist;
-$Scientist::VERSION = '0.003';
+$Scientist::VERSION = '0.004';
 use Moo;
-use Test::Deep::NoTest;
+use Test::Deep::NoTest 'eq_deeply';
+use Time::HiRes 'time';
 
 # ABSTRACT: Perl module inspired by https://github.com/github/scientist
 # https://github.com/lancew/Scientist
@@ -19,12 +20,18 @@ has 'try' => ( is => 'rw' );
 
 sub run {
     my $self = shift;
+    my %result;
 
+    my $start   = Time::HiRes::time;
     my $control = $self->use->();
-    my $candidate = eval { $self->try->() };
-    my $mismatched = !eq_deeply( \$control, \$candidate );
+    $result{control}{duration} = ( Time::HiRes::time - $start );
 
-    $self->result( { mismatched => $mismatched ? 1 : 0 } );
+    $start = Time::HiRes::time;
+    my $candidate = eval { $self->try->() };
+    $result{mismatched} = !eq_deeply( \$control, \$candidate ) ? 1 : 0;
+    $result{candidate}{duration} = ( Time::HiRes::time - $start );
+
+    $self->result( \%result );
 
     return $control;
 }
